@@ -1,21 +1,14 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/ControlStructures/ProhibitUnreachableCode.pm $
-#     $Date: 2010-06-22 16:14:07 -0400 (Tue, 22 Jun 2010) $
-#   $Author: clonezone $
-# $Revision: 3843 $
-##############################################################################
-
 package Perl::Critic::Policy::ControlStructures::ProhibitUnreachableCode;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :data_conversion :classification };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.108';
+our $VERSION = '1.148';
 
 Readonly::Array my @TERMINALS => qw( die exit croak confess );
 Readonly::Hash  my %TERMINALS => hashify( @TERMINALS );
@@ -35,7 +28,7 @@ Readonly::Scalar my $EXPL => q{Consider removing it};
 
 sub supported_parameters { return ()                 }
 sub default_severity     { return $SEVERITY_HIGH     }
-sub default_themes       { return qw( core bugs )    }
+sub default_themes       { return qw( core bugs certrec )    }
 sub applies_to           { return 'PPI::Token::Word' }
 
 #-----------------------------------------------------------------------------
@@ -56,16 +49,16 @@ sub violates {
     return if not is_function_call($elem);
 
     # Scan the enclosing statement for conditional keywords or logical
-    # operators.  If any are found, then this the folowing statements
+    # operators.  If any are found, then this the following statements
     # could _potentially_ be executed, so this policy is satisfied.
 
-    # NOTE: When the first operand in an boolean expression is
+    # NOTE: When the first operand in a boolean expression is
     # C<croak> or C<die>, etc., the second operand is technically
     # unreachable.  But this policy doesn't catch that situation.
 
     for my $child ( $statement->schildren() ) {
-        return if $child->isa('PPI::Token::Operator') && exists $OPERATORS{$child};
-        return if $child->isa('PPI::Token::Word') && exists $CONDITIONALS{$child};
+        return if exists $OPERATORS{$child}    && $child->isa('PPI::Token::Operator');
+        return if exists $CONDITIONALS{$child} && $child->isa('PPI::Token::Word');
     }
 
     return $self->_gather_violations($statement);
@@ -218,7 +211,7 @@ Peter Guzis <pguzis@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Peter Guzis.  All rights reserved.
+Copyright (c) 2006-2011 Peter Guzis.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
