@@ -1,14 +1,14 @@
 package Perl::Critic::Policy::Documentation::RequirePodSections;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :booleans :characters :severities :classification };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.126';
+our $VERSION = '1.148';
 
 #-----------------------------------------------------------------------------
 
