@@ -1,14 +1,14 @@
 package Perl::Critic::Policy::RegularExpressions::ProhibitCaptureWithoutTest;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :booleans :data_conversion :severities };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.126';
+our $VERSION = '1.148';
 
 #-----------------------------------------------------------------------------
 
@@ -146,7 +146,7 @@ sub _is_control_transfer_to_right {
     # appears to throw an exception, and fail otherwise. RT 36081
     my $oper = $match->snext_sibling() or return;   # fail
     my $oper_content = $oper->content();
-    # We do not check 'dor' or '//' because a match failure does not
+    # We do not check '//' because a match failure does not
     # return an undefined value.
     q{or} eq $oper_content
         or q{||} eq $oper_content
@@ -311,18 +311,32 @@ __END__
 
 Perl::Critic::Policy::RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional.
 
-
 =head1 AFFILIATION
 
 This Policy is part of the core L<Perl::Critic|Perl::Critic>
 distribution.
 
-
 =head1 DESCRIPTION
 
 If a regexp match fails, then any capture variables (C<$1>, C<$2>,
-...) will be undefined.  Therefore it's important to check the return
-value of a match before using those variables.
+...) will be unaffected.  They will retain whatever old values they may
+have had.  Therefore it's important to check the return value of a match
+before using those variables.
+
+    '12312123' =~ /(2)/;
+    print $1;    # Prints 2
+    '123123123' =~ /(X)/;
+    print $1;    # Prints 2, because $1 has not changed.
+
+Note that because the values of C<$1> etc will be unaffected, you cannot
+determine if a match succeeded by checking to see if the capture variables
+have values.
+
+    # WRONG
+    $str =~ /foo(.+)/;
+    if ( $1 ) {
+        print "I found $1 after 'foo'";
+    }
 
 This policy checks that the previous regexp for which the capture
 variable is in-scope is either in a conditional or causes an exception
@@ -348,7 +362,7 @@ regexp results, for pretty much the same reason.  Simple things like
 
 will be handled, but something like
 
- m/(foo) or do {
+ m/(foo)/ or do {
    ... lots of complicated calculations here ...
    die "No foo!";
  };
@@ -374,10 +388,9 @@ This policy does not recognize named capture variables. Yet.
 
 Chris Dolan <cdolan@cpan.org>
 
-
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2011 Chris Dolan.
+Copyright (c) 2006-2017 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
