@@ -1,13 +1,6 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/branches/Perl-Critic-With-Param-Validation/lib/Perl/Critic/PolicyListing.pm $
-#     $Date: 2006-12-13 21:35:21 -0800 (Wed, 13 Dec 2006) $
-#   $Author: thaljef $
-# $Revision: 1089 $
-##############################################################################
-
 package Perl::Critic::ProfilePrototype;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -18,7 +11,7 @@ use Perl::Critic::Policy qw{};
 use Perl::Critic::Utils qw{ :characters };
 use overload ( q{""} => 'to_string' );
 
-our $VERSION = '1.092';
+our $VERSION = '1.148';
 
 #-----------------------------------------------------------------------------
 
@@ -29,11 +22,7 @@ sub new {
     my $policies = $args{-policies} || [];
     $self->{_policies} = [ sort _by_type @{ $policies } ];
 
-    my $comment_out_parameters = $args{'-comment-out-parameters'};
-    if (not defined $comment_out_parameters) {
-        $comment_out_parameters = 1;
-    }
-    $self->{_comment_out_parameters} = $comment_out_parameters;
+    $self->{_comment_out_parameters} = $args{'-comment-out-parameters'} // 1;
 
     my $configuration = $args{'-config'};
     if (not $configuration) {
@@ -98,6 +87,11 @@ sub to_string {
     $prototype .= $configuration->only();
     $prototype .= "\n";
 
+    $prototype .= $prefix;
+    $prototype .= q{allow-unsafe = };
+    $prototype .= $configuration->unsafe_allowed();
+    $prototype .= "\n";
+
     $prototype .= $prefix;
     $prototype .= q{profile-strictness = };
     $prototype .= $configuration->profile_strictness();
@@ -143,9 +137,29 @@ sub to_string {
     $prototype .= $configuration->theme()->rule();
     $prototype .= "\n";
 
+    foreach my $item (qw<
+        color-severity-highest
+        color-severity-high
+        color-severity-medium
+        color-severity-low
+        color-severity-lowest
+        >) {
+        ( my $accessor = $item ) =~ s/ - /_/gmsx;
+        $prototype .= $prefix;
+        $prototype .= "$item = ";
+        $prototype .= $configuration->$accessor;
+        $prototype .= "\n";
+    }
+
+    $prototype .= $prefix;
+    $prototype .= q{program-extensions = };
+    $prototype .= join $SPACE, $configuration->program_extensions();
+
     Perl::Critic::Policy::set_format( $self->_proto_format() );
 
-    return $prototype . "\n" . join q{}, map { "$_" } @{ $self->_get_policies() };
+    my $policy_prototypes = join qq{\n}, map { "$_" } @{ $self->_get_policies() };
+    $policy_prototypes =~ s/\s+ \z//xms; # Trim trailing whitespace
+    return $prototype . "\n\n" . $policy_prototypes . "\n";
 }
 
 #-----------------------------------------------------------------------------
@@ -175,7 +189,6 @@ ${prefix}add_themes                         =
 ${prefix}severity                           = %s
 ${prefix}maximum_violations_per_document    = %v
 %{\\n%\\x7b# \\x7df\\n${prefix}%n = %D\\n}O%{${prefix}Cannot programmatically discover what parameters this policy takes.\\n}U
-
 END_OF_FORMAT
 
 }
@@ -202,9 +215,15 @@ L<Perl::Critic|Perl::Critic> profile (e.g. a F<.perlcriticrc> file.
 There are no user-serviceable parts here.
 
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a non-public class.  Its interface is subject
+to change without notice.
+
+
 =head1 CONSTRUCTOR
 
-=over 8
+=over
 
 =item C<< new( -policies => \@POLICY_OBJECTS ) >>
 
@@ -216,7 +235,7 @@ Returns a reference to a new C<Perl::Critic::ProfilePrototype> object.
 
 =head1 METHODS
 
-=over 8
+=over
 
 =item to_string()
 
@@ -242,12 +261,12 @@ file.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
